import java.awt.*;
import java.awt.geom.AffineTransform;
import java.text.*;
import java.lang.*;
import java.io.*;

public class SimpleDataViewer extends Frame {
	int nc;
	SimpleDataViewerCanvas tpt = null;
	SimpleDataViewerPlot grf = null;
	SimpleDataViewer (String title, int m) {
		super (title);
		nc = m;
		grf = new SimpleDataViewerPlot (nc);
	}
	public void init () {
		tpt = new SimpleDataViewerCanvas (this);
		add (tpt);
		pack ();
	}
	public boolean handleEvent(Event evt) {
        	switch (evt.id) {
		case Event.WINDOW_DESTROY:
			System.exit(0);
		case Event.MOUSE_DOWN:
			tpt.saveEps ();
		}
	return super.handleEvent(evt);
	}
}
class SimpleDataViewerCanvas extends Canvas {
	int nc;
	int frameWidth = 500;
	int frameHeight = 375;
	int offx = 50;
	int offy = 38;
	int fontStyle1 = 0;
	int fontSize1 = 15;
	String virtualFont1 = "Monospaced";
	int fontStyle2 = 0;
	int fontSize2 = 10;
	String virtualFont2 = "Monospaced";
	int tickLength1 = 10;
	int tickLength2 = 10;
	int tickSeparation1 = 10;
	int tickSeparation2 = 20;
	int numberOfDecimals = 2;
	int feps = 16;
	Font fontx1, fonty1, fontx2, fonty2;
	String presentColor = "col0";
	AffineTransform rot;
	FileWriter output = null;
	SimpleDataViewer sdv;
	Dimension minSize;
	SimpleDataViewerCanvas (Frame base) {
		super ();
		sdv = (SimpleDataViewer) base;
		nc = sdv.nc;
		minSize = new Dimension (600,450);
		fontx1 = new Font (virtualFont1, fontStyle1, fontSize1);
		fontx2 = new Font (virtualFont2, fontStyle2, fontSize2);
		rot = new AffineTransform (0.0, -1.0, 1.0, 0.0, 0.0, 0.0);
		fonty1 = fontx1.deriveFont (rot);
		fonty2 = fontx2.deriveFont (rot);
	}
	public Dimension preferredSize () {
		return minimumSize ();
	}
	public synchronized Dimension minimumSize () {
		return minSize;
	}
	public void paint (Graphics g) {
		int i;
		sdv.grf.autoRange ();
		drawFrame (g);
		drawLabels (g);
		drawTicks (g);
		for (i = 0; i < nc; i++) drawSet (g, i);
	}
	public void printEps () {
		int i;
		Graphics h = null;
		beginEps ();
		drawFrame (h);
		drawLabels (h);
		drawTicks (h);
		for (i = 0; i < nc; i++) drawSet (h, i);
		endEps ();
	}
	void drawFrame (Graphics g) {
		 drawRectSDV (g, offx, offy, frameWidth, frameHeight);
	}
	void drawSet (Graphics g, int m) {
		int d, i, n, tp, tl, x[], y[];
		String ca = "";
		Color c = null;
		x = xcoords(m);
		y = ycoords(m);
		n = x.length;
		d = sdv.grf.cjt[m].pointSize;
		tp = sdv.grf.cjt[m].pointType;
		tl = sdv.grf.cjt[m].lineType;
		if (g != null)
			c = g.getColor ();
		else
			ca = presentColor;
		setColorSDV (g, m);
		if (tp == 1) 
			for (i = 0; i < n; i++) {
				drawOvalSDV (g, x[i], y[i], d, d);
			}
		else if (tp == 2) 
			for (i = 0; i < n; i++) {
				fillOvalSDV (g, x[i], y[i], d, d);
			}
		if (tl == 1)
			for (i = 1; i < n; i++) {
				drawLineSDV (g, x[i-1], y[i-1], x[i], y[i]);
			}
		if (g != null) 
			g.setColor(c);
		else
			presentColor = ca;
	}
	void drawLabels (Graphics g) {
		drawTextSDV (g, sdv.grf.lx, offx + frameWidth/2, offy/2, 1, 1);
		drawTextSDV (g, sdv.grf.ly, offx/2, offy + frameHeight/2, 2, 1);
	}
	void drawTicks (Graphics g) {
		int i, j, n;
		double a, xmin, xmax, xtl, ymin, ymax, ytl;
		NumberFormat nf;
		nf = NumberFormat.getInstance ();
		nf.setMaximumFractionDigits (numberOfDecimals);
		xmin = sdv.grf.xmin;
		xmax = sdv.grf.xmax;
		xtl = sdv.grf.xtl;
		ymin = sdv.grf.ymin;
		ymax = sdv.grf.ymax;
		ytl = sdv.grf.ytl;
		a = (xmax - xmin)/xtl - 1.0;
		n = (int) a;
		for (i = 1; i <= n; i++) {
			a = frameWidth*xtl*i/(xmax - xmin);
			j = (int) a;
			drawLineSDV (g, offx + j, offy, offx + j, offy + tickLength1);
			drawLineSDV (g, offx + j, offy + frameHeight, offx + j, offy + frameHeight - tickLength1);
			drawTextSDV (g, nf.format (xmin + xtl*i), offx + j, offy + frameHeight + tickSeparation1, 1, 2);
		}
		a = (ymax - ymin)/ytl - 1.0;
		n = (int) a;
		for (i = 1; i <= n; i++) {
			a = frameHeight*ytl*i/(ymax - ymin);
			j = (int) a;
			drawLineSDV (g, offx, offy + frameHeight - j, offx + tickLength2, offy + frameHeight -j);
			drawLineSDV (g, offx + frameWidth, offy + frameHeight - j, offx + frameWidth - tickLength2, offy + frameHeight - j);
			drawTextSDV (g, nf.format (ymin + ytl*i), offx + frameWidth + tickSeparation2, offy + frameHeight -j, 1, 2);
		}
	}
	void drawTextSDV (Graphics g, String t, int x, int y, int o, int m) {
		int a, b, mdl, n;
		n = t.length ();
		if (m == 1)
			mdl = fontSize1;
		else if (m == 2)
			mdl = fontSize2;
		else
			mdl = fontSize1;
		if (o == 1) {
			a = x - mdl*n/3;
			b = y + mdl/2;
		} else if (o == 2) {
			a = x + mdl/2;
			b = y + mdl*n/3;
		} else {
			a = x - mdl*n/3;
			b = y + mdl/2;
		}
		drawStringSDV (g, t, a, b, o, m);
	}
	void drawLineSDV (Graphics g, int x1, int y1, int x2, int y2) {
		if (g != null) 
			g.drawLine (x1, y1, x2, y2);
		else {
			try {
				output.write ("% Polyline\n");
				output.write ("n " + Integer.toString (x1*feps) + " " + Integer.toString (y1*feps) + " m\n");
				output.write (Integer.toString (x2*feps) + " " + Integer.toString (y2*feps) + " l gs " + presentColor + " s gr \n");
			} catch (IOException e){}
		}
	}
	void drawRectSDV (Graphics g, int x1, int y1, int x2, int y2) {
		if (g != null) 
			g.drawRect (x1, y1, x2, y2);
		else {
			try {
				output.write ("% Polyline\n");
				output.write ("n " + Integer.toString (x1*feps) + " " + Integer.toString (y1*feps) + " m " + Integer.toString ((x1 + x2)*feps) + " " + Integer.toString (y1*feps) + " l " + Integer.toString ((x1 + x2)*feps) + " " + Integer.toString ((y1 + y2)*feps) + " l " + Integer.toString (x1*feps) + " " + Integer.toString ((y1 + y2)*feps) + " l\n");
				output.write (" cp gs " + presentColor + " s gr\n"); 
			} catch (IOException e){}
		}
	}
	void drawOvalSDV (Graphics g, int x, int y, int dx, int dy) {
		if (g != null) 
			g.drawOval (x - dx/2, y - dy/2, dx, dy);
		else {
			try {
				output.write ("% Ellipse\n");
				output.write ("n " + Integer.toString (x*feps) + " " + Integer.toString (y*feps) + " " + Integer.toString (dx*feps/2) + " " + Integer.toString (dy*feps/2) + " 0 360 DrawEllipse gs " + presentColor + " s gr \n");
			} catch (IOException e){}
		}
	}
	void fillOvalSDV (Graphics g, int x, int y, int dx, int dy) {
		if (g != null) 
			g.fillOval (x - dx/2, y - dy/2, dx, dy);
		else {
			try {
				output.write ("% Ellipse\n");
				output.write ("n " + Integer.toString (x*feps) + " " + Integer.toString (y*feps) + " " + Integer.toString (dx*feps/2) + " " + Integer.toString (dy*feps/2) + " 0 360 DrawEllipse gs " + presentColor + " 1.00 shd ef gr gs " + presentColor + " s gr \n");
			} catch (IOException e){}
		}
	}
	void drawStringSDV (Graphics g, String s, int x, int y, int o, int m) {
		String ml, or;
		if (g != null) {
				if (m == 1 && o == 1)
					g.setFont (fontx1);
				else if (m == 1 && o == 2)
					g.setFont (fonty1);
				else if (m == 2 && o == 1)
					g.setFont (fontx2);
				else if (m == 2 && o == 2)
					g.setFont (fonty2);
				else
					g.setFont (fontx1);
			g.drawString (s, x, y);
		} else {
				if (m == 1)
					ml = "225.00";
				else if (m == 2)
					ml = "150.00";
				else
					ml = "225.00";;
				if (o == 1)
					or = "";
				else if (o == 2)
					or = "90.0 rot";
				else
					or = "";
			try {
				output.write ("/Courier ff " + ml + " scf sf \n");
				output.write (Integer.toString (x*feps) + " " + Integer.toString (y*feps) + " m \n");
				output.write ("gs 1 -1 sc " + or + " (" + s + ") col0 sh gr \n");
			} catch (IOException e){}
		}
	}
	int[] xcoords (int i) {
		int j, k[], n;
		double a, xmin, xmax;
		xmin = sdv.grf.xmin;
		xmax = sdv.grf.xmax;
		n = sdv.grf.cjt[i].n;
		k = new int[n];
		for (j = 0; j < n; j++) {
			a = frameWidth*(sdv.grf.cjt[i].x[j] - xmin)/(xmax - xmin);
			k[j] = (int) a;
			k[j] = k[j] + offx;
		} 
	return k;
	}
	int[] ycoords (int i) {
		int j, k[], n;
		double a, ymin, ymax;
		ymin = sdv.grf.ymin;
		ymax = sdv.grf.ymax;
		n = sdv.grf.cjt[i].n;
		k = new int[n];
		for (j = 0; j < n; j++) {
			a = (sdv.grf.cjt[i].y[j] - ymin)/(ymax - ymin);
			a = frameHeight*(1.0 - a);
			k[j] = (int) a;
			k[j] = k[j] + offy;
		} 
	return k;
	}
	void setColorSDV (Graphics g, int m) {
		int i;
		i = sdv.grf.cjt[m].color;
		if (g != null) {
			if (i == 5)
				g.setColor (Color.magenta);
			else if (i == 4)
				g.setColor (Color.blue);
			else if (i == 3)
				g.setColor (Color.green);
			else if (i == 2)
				g.setColor (Color.red);
			else
				g.setColor (Color.black);
		} else {
			if (i == 5)
				presentColor = "col5";
			else if (i == 4)
				presentColor = "col1";
			else if (i == 3)
				presentColor = "col2";
			else if (i == 2)
				presentColor = "col4";
			else
				presentColor = "col0";
		}
	}
	void beginEps () {
		try {
			output.write ("%!PS-Adobe-2.0 EPSF-2.0\n");
			output.write ("%%Creator: SDV (based on fig2dev Version 3.2 Patchlevel 4)\n");
			output.write ("%%BoundingBox: 0 0 578 434\n");
			output.write ("%%Magnification: 1.0000\n");
			output.write ("%%EndComments\n");
			output.write ("/$F2psDict 200 dict def\n");
			output.write ("$F2psDict begin\n");
			output.write ("$F2psDict /mtrx matrix put\n");
			output.write ("/col-1 {0 setgray} bind def\n");
			output.write ("/col0 {0.000 0.000 0.000 srgb} bind def\n");
			output.write ("/col1 {0.000 0.000 1.000 srgb} bind def\n");
			output.write ("/col2 {0.000 1.000 0.000 srgb} bind def\n");
			output.write ("/col3 {0.000 1.000 1.000 srgb} bind def\n");
			output.write ("/col4 {1.000 0.000 0.000 srgb} bind def\n");
			output.write ("/col5 {1.000 0.000 1.000 srgb} bind def\n");
			output.write ("/col6 {1.000 1.000 0.000 srgb} bind def\n");
			output.write ("/col7 {1.000 1.000 1.000 srgb} bind def\n");
			output.write ("/col8 {0.000 0.000 0.560 srgb} bind def\n");
			output.write ("/col9 {0.000 0.000 0.690 srgb} bind def\n");
			output.write ("/col10 {0.000 0.000 0.820 srgb} bind def\n");
			output.write ("/col11 {0.530 0.810 1.000 srgb} bind def\n");
			output.write ("/col12 {0.000 0.560 0.000 srgb} bind def\n");
			output.write ("/col13 {0.000 0.690 0.000 srgb} bind def\n");
			output.write ("/col14 {0.000 0.820 0.000 srgb} bind def\n");
			output.write ("/col15 {0.000 0.560 0.560 srgb} bind def\n");
			output.write ("/col16 {0.000 0.690 0.690 srgb} bind def\n");
			output.write ("/col17 {0.000 0.820 0.820 srgb} bind def\n");
			output.write ("/col18 {0.560 0.000 0.000 srgb} bind def\n");
			output.write ("/col19 {0.690 0.000 0.000 srgb} bind def\n");
			output.write ("/col20 {0.820 0.000 0.000 srgb} bind def\n");
			output.write ("/col21 {0.560 0.000 0.560 srgb} bind def\n");
			output.write ("/col22 {0.690 0.000 0.690 srgb} bind def\n");
			output.write ("/col23 {0.820 0.000 0.820 srgb} bind def\n");
			output.write ("/col24 {0.500 0.190 0.000 srgb} bind def\n");
			output.write ("/col25 {0.630 0.250 0.000 srgb} bind def\n");
			output.write ("/col26 {0.750 0.380 0.000 srgb} bind def\n");
			output.write ("/col27 {1.000 0.500 0.500 srgb} bind def\n");
			output.write ("/col28 {1.000 0.630 0.630 srgb} bind def\n");
			output.write ("/col29 {1.000 0.750 0.750 srgb} bind def\n");
			output.write ("/col30 {1.000 0.880 0.880 srgb} bind def\n");
			output.write ("/col31 {1.000 0.840 0.000 srgb} bind def\n");
			output.write ("\n");
			output.write ("end\n");
			output.write ("save\n");
			output.write ("newpath 0 434 moveto 0 0 lineto 578 0 lineto 578 434 lineto closepath clip newpath\n");
			output.write ("0.7 432.7 translate\n");
			output.write ("1 -1 scale\n");
			output.write ("\n");
			output.write ("/cp {closepath} bind def\n");
			output.write ("/ef {eofill} bind def\n");
			output.write ("/gr {grestore} bind def\n");
			output.write ("/gs {gsave} bind def\n");
			output.write ("/sa {save} bind def\n");
			output.write ("/rs {restore} bind def\n");
			output.write ("/l {lineto} bind def\n");
			output.write ("/m {moveto} bind def\n");
			output.write ("/rm {rmoveto} bind def\n");
			output.write ("/n {newpath} bind def\n");
			output.write ("/s {stroke} bind def\n");
			output.write ("/sh {show} bind def\n");
			output.write ("/slc {setlinecap} bind def\n");
			output.write ("/slj {setlinejoin} bind def\n");
			output.write ("/slw {setlinewidth} bind def\n");
			output.write ("/srgb {setrgbcolor} bind def\n");
			output.write ("/rot {rotate} bind def\n");
			output.write ("/sc {scale} bind def\n");
			output.write ("/sd {setdash} bind def\n");
			output.write ("/ff {findfont} bind def\n");
			output.write ("/sf {setfont} bind def\n");
			output.write ("/scf {scalefont} bind def\n");
			output.write ("/sw {stringwidth} bind def\n");
			output.write ("/tr {translate} bind def\n");
			output.write ("/tnt {dup dup currentrgbcolor\n");
			output.write ("  4 -2 roll dup 1 exch sub 3 -1 roll mul add\n");
			output.write ("  4 -2 roll dup 1 exch sub 3 -1 roll mul add\n");
			output.write ("  4 -2 roll dup 1 exch sub 3 -1 roll mul add srgb}\n");
			output.write ("  bind def\n");
			output.write ("/shd {dup dup currentrgbcolor 4 -2 roll mul 4 -2 roll mul\n");
			output.write ("  4 -2 roll mul srgb} bind def\n");
			output.write (" /DrawEllipse {\n");
			output.write ("	/endangle exch def\n");
			output.write ("	/startangle exch def\n");
			output.write ("	/yrad exch def\n");
			output.write ("	/xrad exch def\n");
			output.write ("	/y exch def\n");
			output.write ("	/x exch def\n");
			output.write ("	/savematrix mtrx currentmatrix def\n");
			output.write ("	x y tr xrad yrad sc 0 0 1 startangle endangle arc\n");
			output.write ("	closepath\n");
			output.write ("	savematrix setmatrix\n");
			output.write ("	} def\n");
			output.write ("\n");
			output.write ("/$F2psBegin {$F2psDict begin /$F2psEnteredState save def} def\n");
			output.write ("/$F2psEnd {$F2psEnteredState restore end} def\n");
			output.write ("\n");
			output.write ("$F2psBegin\n");
			output.write ("10 setmiterlimit\n");
			output.write ("0 slj 0 slc\n");
			output.write (" 0.06000 0.06000 sc\n");
			output.write ("%\n");
			output.write ("% SDV objects follow\n");
			output.write ("%\n");
			output.write ("% here starts figure with depth 50\n");
			output.write ("7.500 slw\n");
			output.write ("%\n");
		} catch (IOException e){}
	}
	void endEps () {
		try {
			output.write ("% here ends figure;\n");
			output.write ("$F2psEnd\n");
			output.write ("rs\n");
			output.write ("showpage\n");
			output.write ("\n");
		} catch (IOException e){}
	}
	public void saveEps() {
		File outputFile;
		boolean writeSDV = true;
		try {
			outputFile = askForFile ();
			if (outputFile != null) {
				writeSDV = !outputFile.exists ();
				if (!writeSDV)
					writeSDV = askForConfirmation ();
				if(writeSDV) {
					output = new FileWriter (outputFile);
					printEps ();
					output.close ();
				}
			}
		} catch (IOException e){}
	}
	public boolean askForConfirmation () {
		SimpleDataViewerConfirm confirm = null ;
		boolean option = false;
		if (confirm == null)
			confirm = new SimpleDataViewerConfirm (sdv);
		confirm.show ();
		option = confirm.getOpcio ();
		return option;
	}
	public File askForFile() {
		FileDialog chooseOutputFile = null ;
		File outputFile;
		String folderName = "./";
		String name = "sensenom.eps";

		outputFile = new File (folderName, name);
			try {
				chooseOutputFile = new FileDialog (sdv, "Desa com a EPS", chooseOutputFile.SAVE);
				chooseOutputFile.setFile (name);
				chooseOutputFile.show ();
				name = chooseOutputFile.getFile ();
				folderName = chooseOutputFile.getDirectory ();
				outputFile = new File (folderName, name);
			} catch (NullPointerException e) {
				outputFile = null;
				name = "sensenom.eps";
			}
		return outputFile;
	}
}
class SimpleDataViewerConfirm extends Dialog {
	Button c1;
	Button c2;
	Label l1;
	boolean option = false;
	SimpleDataViewerConfirm (Frame sdv) {
		super (sdv, "Confirma", true);
		setLayout (new GridLayout (0, 1, 10, 10));
		c1 = new Button ("D'acord");
		c2 = new Button ("Cancel.la");
		l1 = new Label  ("  El fitxer ja existeix. Vols escriure a sobre?");
		add (l1);
		add (c1);
		add (c2);
		pack ();
	}
	public boolean action (Event evt,Object arg) {
		if (evt.target instanceof Button) return accioBoto((String) arg);
		return true;
	}
	public boolean accioBoto (String label) {
		if (label.equals ("D'acord")) {
			option = true;
			hide ();
		}
		if (label.equals ("Cancel.la")) {
			option = false;
			hide ();
		}
		return true;
	}
	public boolean getOpcio() {
	return option;
	}
}
class SimpleDataViewerPlot {
	int nc;
	double xmin = 0.0;
	double ymin = 0.0;
	double xmax = 1.0;
	double ymax = 1.0;
	double xtl = 0.2;
	double ytl = 0.2;
	String lx = "Eix x (u.arb.)";
	String ly = "Eix y (u.arb.)";
	SimpleDataViewerSet cjt[];
	SimpleDataViewerPlot (int m) {
		int i;
		nc = m;
		cjt = new SimpleDataViewerSet[nc];
		for (i = 0; i < nc; i++) cjt[i] = new SimpleDataViewerSet ();
	}
	void autoRange () {
		int i, j, l, n;
		double min, max, delta;
		min = 0.0;
		max = 0.0;
		for (i = 0; i < nc; i++) {
			n = cjt[i].x.length;
//			min = cjt[i].x[0];
//			max = cjt[i].x[0];
			for (j = 1; j < n; j++) {
				if (cjt[i].x[j] > max) max = cjt[i].x[j];
				if (cjt[i].x[j] < min) min = cjt[i].x[j];
			}
		}
		delta = Math.rint (Math.log (max - min)/Math.E);
		xtl = Math.pow (10.0, delta-1.0);
		if ((max - min)/xtl > 10.0) xtl = xtl*2.0;
		if ((max - min)/xtl > 10.0) xtl = xtl*5.0/2.0;
		if ((max - min)/xtl < 5.0) xtl = xtl/2.0;
		if ((max - min)/xtl < 5.0) xtl = xtl*2.0/5.0;
		xmin = xtl*Math.floor (min/xtl);
		xmax = xtl*Math.ceil (max/xtl);
//		xmin = Math.pow (10.0, -delta)*Math.floor (min*Math.pow (10.0, delta));
//		xmax = Math.pow (10.0, -delta)*Math.ceil (max*Math.pow (10.0, delta));
		min = 0.0;
		max = 0.0;
		for (i = 0; i < nc; i++) {
			n = cjt[i].y.length;
//			min = cjt[i].y[0];
//			max = cjt[i].y[0];
			for (j = 1; j < n; j++) {
				if (cjt[i].y[j] > max) max = cjt[i].y[j];
				if (cjt[i].y[j] < min) min = cjt[i].y[j];
			}
		}
		delta = Math.rint (Math.log (max - min)/Math.E);
		ytl = Math.pow (10.0, delta-1.0);
		if ((max - min)/ytl > 10.0) ytl = ytl*2.0;
		if ((max - min)/ytl > 10.0) ytl = ytl*5.0/2.0;
		if ((max - min)/ytl < 5.0) ytl = ytl/2.0;
		if ((max - min)/ytl < 5.0) ytl = ytl*2.0/5.0;
		ymin = ytl*Math.floor (min/ytl);
		ymax = ytl*Math.ceil (max/ytl); 
//		ymin = Math.pow (10.0, -delta)*Math.floor (min*Math.pow (10.0, delta));
//		ymax = Math.pow (10.0, -delta)*Math.ceil (max*Math.pow (10.0, delta));
		}
}
class SimpleDataViewerSet {
	double x[], y[];
	int j, n, nx, ny;
	int color = 0;
	int pointSize = 10; 
	int pointType = 1;
	int lineSize = 1;
	int lineType = 1;
	SimpleDataViewerSet () {
	}
	SimpleDataViewerSet (int i) {
		initializeColor (i);
	}
	SimpleDataViewerSet (double f1[], double f2[]) {
		initializeCoordinates (f1, f2);
	}
	SimpleDataViewerSet (int i, double f1[], double f2[]) {
		initializeColor (i);
		initializeCoordinates (f1, f2);
	}
	void initializeColor (int i) {
		color = i;
	}
	void initializeCoordinates (double f1[], double f2[]) {
		x = f1;
		y = f2;
		nx = x.length;
		ny = y.length;
		if (nx < ny)
			n = nx;
		else
			n = ny;
	}
	void printSet () {
		System.out.println ("Color: " + color);
		System.out.println ("Mida dels punts: " + pointSize);
		System.out.println ("Tipus de punts: " + pointType);
		System.out.println ("Mida de linia: " + lineSize);
		System.out.println ("Tipus de linia: " + lineType);
		System.out.println ("Nombre de coords. x: " + nx);
		System.out.println ("Nombre de coords. y: " + ny);
		System.out.println ("Nombre de punts: " + n);
		for (j = 0; j < n ; j++) {
			System.out.println("Coords. punt " + j);
			System.out.println(x[j]);
			System.out.println(y[j]);
		}
	}
}
